These functions generate parameters that are useful for neural network models.
Usage
dropout(range = c(0, 1), trans = NULL)
epochs(range = c(10L, 1000L), trans = NULL)
hidden_units(range = c(1L, 10L), trans = NULL)
hidden_units_2(range = c(1L, 10L), trans = NULL)
batch_size(range = c(2L, 7L), trans = transform_log2())
dropout_hidden(range = c(0, 0.5), trans = NULL)
dropout_last(range = c(0, 0.5), trans = NULL)
num_embedding(range = c(8L, 64L), trans = NULL)
dropout_embedding(range = c(0, 0.5), trans = NULL)Arguments
- range
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.
- trans
A
transobject from thescalespackage, such asscales::transform_log10()orscales::transform_reciprocal(). If not provided, the default is used which matches the units used inrange. If no transformation,NULL.
Details
dropout(): The parameter dropout rate. (Seeparsnip:::mlp()).epochs(): The number of iterations of training. (Seeparsnip:::mlp()).hidden_units(): The number of hidden units in a network layer. (Seeparsnip:::mlp()).batch_size(): The mini-batch size for neural networks.dropout_hidden(): The proportion of hidden-layer units to randomly set to zero during model training.dropout_last(): The proportion of final-layer units to randomly set to zero during model training.num_embedding(): The dimensionality of the embedding space for features.dropout_embedding(): The proportion of embedding values to randomly set to zero during model training.