These parameters are auxiliary to tree-based models that use the "catboost"
engine. They correspond to tuning parameters that would be specified using
set_engine("catboost", ...).
Arguments
- range
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.
- trans
A
transobject from thescalespackage, such asscales::transform_log10()orscales::transform_reciprocal(). If not provided, the default is used which matches the units used inrange. If no transformation,NULL.
Details
"catboost" is an available engine in the parsnip extension package bonsai
max_leaves() is only used when the grow policy is set to "Lossguide".
For more information, see the catboost webpage.