These parameters are used with tabular residual networks, such as
tabular_resnet() when fit with the brulee engine.
Arguments
- range
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units.
- trans
A
transobject from thescalespackage, such asscales::transform_log10()orscales::transform_reciprocal(). If not provided, the default is used which matches the units used inrange. If no transformation,NULL.
Details
bottleneck_units(): The number of units used in ResNet layers within a residual block.resid_at(): The layer indices at which residual connections are added. The upper bound depends on the number of hidden layers in the network and so is left asunknown()by default.